==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/nonconformity_001/TrackingDetails.java <==

package net.datastream.schemas.mp_entities.nonconformity_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CAPITALPLANREQUESTID_Type;
import net.datastream.schemas.mp_fields.CURRENCYID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CONDITIONSCORE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CONDITIONINDEX" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NEXTINSPECTIONDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NEXTINSPECTIONDATEOVERRIDE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SOURCEOBSERVATIONNUM" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}OVERRIDEOBSERVATION" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RECOMMENDEDREPAIRDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CURRENCYID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDLABORCOST" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDMATERIALCOST" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDMISCELLANEOUSCOST" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDTOTALCOST" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CAPITALPLANREQUESTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYMERGEINTO" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}UPDATEDBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DATEUPDATED" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "conditionscore",
    "conditionindex",
    "nextinspectiondate",
    "nextinspectiondateoverride",
    "sourceobservationnum",
    "overrideobservation",
    "recommendedrepairdate",
    "currencyid",
    "estimatedlaborcost",
    "estimatedmaterialcost",
    "estimatedmiscellaneouscost",
    "estimatedtotalcost",
    "capitalplanrequestid",
    "nonconformitymergeinto",
    "createddate",
    "createdby",
    "updatedby",
    "dateupdated"
})
@XmlRootElement(name = "TrackingDetails")
public class TrackingDetails {

    @XmlElement(name = "CONDITIONSCORE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY conditionscore;
    @XmlElement(name = "CONDITIONINDEX", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type conditionindex;
    @XmlElement(name = "NEXTINSPECTIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME nextinspectiondate;
    @XmlElement(name = "NEXTINSPECTIONDATEOVERRIDE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME nextinspectiondateoverride;
    @XmlElement(name = "SOURCEOBSERVATIONNUM", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY sourceobservationnum;
    @XmlElement(name = "OVERRIDEOBSERVATION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String overrideobservation;
    @XmlElement(name = "RECOMMENDEDREPAIRDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME recommendedrepairdate;
    @XmlElement(name = "CURRENCYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type currencyid;
    @XmlElement(name = "ESTIMATEDLABORCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedlaborcost;
    @XmlElement(name = "ESTIMATEDMATERIALCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedmaterialcost;
    @XmlElement(name = "ESTIMATEDMISCELLANEOUSCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedmiscellaneouscost;
    @XmlElement(name = "ESTIMATEDTOTALCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedtotalcost;
    @XmlElement(name = "CAPITALPLANREQUESTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CAPITALPLANREQUESTID_Type capitalplanrequestid;
    @XmlElement(name = "NONCONFORMITYMERGEINTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected String nonconformitymergeinto;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "UPDATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type updatedby;
    @XmlElement(name = "DATEUPDATED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateupdated;

    /**
     * Gets the value of the conditionscore property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getCONDITIONSCORE() {
        return conditionscore;
    }

    /**
     * Sets the value of the conditionscore property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setCONDITIONSCORE(QUANTITY value) {
        this.conditionscore = value;
    }

    /**
     * Gets the value of the conditionindex property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getCONDITIONINDEX() {
        return conditionindex;
    }

    /**
     * Sets the value of the conditionindex property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setCONDITIONINDEX(USERDEFINEDCODEID_Type value) {
        this.conditionindex = value;
    }

    /**
     * Gets the value of the nextinspectiondate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getNEXTINSPECTIONDATE() {
        return nextinspectiondate;
    }

    /**
     * Sets the value of the nextinspectiondate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setNEXTINSPECTIONDATE(DATETIME value) {
        this.nextinspectiondate = value;
    }

    /**
     * Gets the value of the nextinspectiondateoverride property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getNEXTINSPECTIONDATEOVERRIDE() {
        return nextinspectiondateoverride;
    }

    /**
     * Sets the value of the nextinspectiondateoverride property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setNEXTINSPECTIONDATEOVERRIDE(DATETIME value) {
        this.nextinspectiondateoverride = value;
    }

    /**
     * Gets the value of the sourceobservationnum property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSOURCEOBSERVATIONNUM() {
        return sourceobservationnum;
    }

    /**
     * Sets the value of the sourceobservationnum property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSOURCEOBSERVATIONNUM(QUANTITY value) {
        this.sourceobservationnum = value;
    }

    /**
     * Gets the value of the overrideobservation property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOVERRIDEOBSERVATION() {
        return overrideobservation;
    }

    /**
     * Sets the value of the overrideobservation property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOVERRIDEOBSERVATION(String value) {
        this.overrideobservation = value;
    }

    /**
     * Gets the value of the recommendedrepairdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getRECOMMENDEDREPAIRDATE() {
        return recommendedrepairdate;
    }

    /**
     * Sets the value of the recommendedrepairdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setRECOMMENDEDREPAIRDATE(DATETIME value) {
        this.recommendedrepairdate = value;
    }

    /**
     * Gets the value of the currencyid property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getCURRENCYID() {
        return currencyid;
    }

    /**
     * Sets the value of the currencyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setCURRENCYID(CURRENCYID_Type value) {
        this.currencyid = value;
    }

    /**
     * Gets the value of the estimatedlaborcost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDLABORCOST() {
        return estimatedlaborcost;
    }

    /**
     * Sets the value of the estimatedlaborcost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDLABORCOST(AMOUNT value) {
        this.estimatedlaborcost = value;
    }

    /**
     * Gets the value of the estimatedmaterialcost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDMATERIALCOST() {
        return estimatedmaterialcost;
    }

    /**
     * Sets the value of the estimatedmaterialcost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDMATERIALCOST(AMOUNT value) {
        this.estimatedmaterialcost = value;
    }

    /**
     * Gets the value of the estimatedmiscellaneouscost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDMISCELLANEOUSCOST() {
        return estimatedmiscellaneouscost;
    }

    /**
     * Sets the value of the estimatedmiscellaneouscost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDMISCELLANEOUSCOST(AMOUNT value) {
        this.estimatedmiscellaneouscost = value;
    }

    /**
     * Gets the value of the estimatedtotalcost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDTOTALCOST() {
        return estimatedtotalcost;
    }

    /**
     * Sets the value of the estimatedtotalcost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDTOTALCOST(AMOUNT value) {
        this.estimatedtotalcost = value;
    }

    /**
     * Gets the value of the capitalplanrequestid property.
     * 
     * @return
     *     possible object is
     *     {@link CAPITALPLANREQUESTID_Type }
     *     
     */
    public CAPITALPLANREQUESTID_Type getCAPITALPLANREQUESTID() {
        return capitalplanrequestid;
    }

    /**
     * Sets the value of the capitalplanrequestid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAPITALPLANREQUESTID_Type }
     *     
     */
    public void setCAPITALPLANREQUESTID(CAPITALPLANREQUESTID_Type value) {
        this.capitalplanrequestid = value;
    }

    /**
     * Gets the value of the nonconformitymergeinto property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNONCONFORMITYMERGEINTO() {
        return nonconformitymergeinto;
    }

    /**
     * Sets the value of the nonconformitymergeinto property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNONCONFORMITYMERGEINTO(String value) {
        this.nonconformitymergeinto = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the createdby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Sets the value of the createdby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Gets the value of the updatedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Sets the value of the updatedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

    /**
     * Gets the value of the dateupdated property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUPDATED() {
        return dateupdated;
    }

    /**
     * Sets the value of the dateupdated property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUPDATED(DATETIME value) {
        this.dateupdated = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_entities/nonconformity_001/TrackingDetails.java <==

package net.datastream.schemas.mp_entities.nonconformity_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CAPITALPLANREQUESTID_Type;
import net.datastream.schemas.mp_fields.CURRENCYID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONDITIONSCORE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONDITIONINDEX" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEXTINSPECTIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEXTINSPECTIONDATEOVERRIDE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOURCEOBSERVATIONNUM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OVERRIDEOBSERVATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RECOMMENDEDREPAIRDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDLABORCOST" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDMATERIALCOST" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDMISCELLANEOUSCOST" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDTOTALCOST" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAPITALPLANREQUESTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYMERGEINTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPDATEDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEUPDATED" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "conditionscore",
    "conditionindex",
    "nextinspectiondate",
    "nextinspectiondateoverride",
    "sourceobservationnum",
    "overrideobservation",
    "recommendedrepairdate",
    "currencyid",
    "estimatedlaborcost",
    "estimatedmaterialcost",
    "estimatedmiscellaneouscost",
    "estimatedtotalcost",
    "capitalplanrequestid",
    "nonconformitymergeinto",
    "createddate",
    "createdby",
    "updatedby",
    "dateupdated"
})
@XmlRootElement(name = "TrackingDetails")
public class TrackingDetails {

    @XmlElement(name = "CONDITIONSCORE", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY conditionscore;
    @XmlElement(name = "CONDITIONINDEX", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type conditionindex;
    @XmlElement(name = "NEXTINSPECTIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME nextinspectiondate;
    @XmlElement(name = "NEXTINSPECTIONDATEOVERRIDE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME nextinspectiondateoverride;
    @XmlElement(name = "SOURCEOBSERVATIONNUM", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY sourceobservationnum;
    @XmlElement(name = "OVERRIDEOBSERVATION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String overrideobservation;
    @XmlElement(name = "RECOMMENDEDREPAIRDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME recommendedrepairdate;
    @XmlElement(name = "CURRENCYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CURRENCYID_Type currencyid;
    @XmlElement(name = "ESTIMATEDLABORCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedlaborcost;
    @XmlElement(name = "ESTIMATEDMATERIALCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedmaterialcost;
    @XmlElement(name = "ESTIMATEDMISCELLANEOUSCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedmiscellaneouscost;
    @XmlElement(name = "ESTIMATEDTOTALCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT estimatedtotalcost;
    @XmlElement(name = "CAPITALPLANREQUESTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CAPITALPLANREQUESTID_Type capitalplanrequestid;
    @XmlElement(name = "NONCONFORMITYMERGEINTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected String nonconformitymergeinto;
    @XmlElement(name = "CREATEDDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME createddate;
    @XmlElement(name = "CREATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type createdby;
    @XmlElement(name = "UPDATEDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type updatedby;
    @XmlElement(name = "DATEUPDATED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME dateupdated;

    /**
     * Gets the value of the conditionscore property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getCONDITIONSCORE() {
        return conditionscore;
    }

    /**
     * Sets the value of the conditionscore property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setCONDITIONSCORE(QUANTITY value) {
        this.conditionscore = value;
    }

    /**
     * Gets the value of the conditionindex property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getCONDITIONINDEX() {
        return conditionindex;
    }

    /**
     * Sets the value of the conditionindex property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setCONDITIONINDEX(USERDEFINEDCODEID_Type value) {
        this.conditionindex = value;
    }

    /**
     * Gets the value of the nextinspectiondate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getNEXTINSPECTIONDATE() {
        return nextinspectiondate;
    }

    /**
     * Sets the value of the nextinspectiondate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setNEXTINSPECTIONDATE(DATETIME value) {
        this.nextinspectiondate = value;
    }

    /**
     * Gets the value of the nextinspectiondateoverride property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getNEXTINSPECTIONDATEOVERRIDE() {
        return nextinspectiondateoverride;
    }

    /**
     * Sets the value of the nextinspectiondateoverride property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setNEXTINSPECTIONDATEOVERRIDE(DATETIME value) {
        this.nextinspectiondateoverride = value;
    }

    /**
     * Gets the value of the sourceobservationnum property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSOURCEOBSERVATIONNUM() {
        return sourceobservationnum;
    }

    /**
     * Sets the value of the sourceobservationnum property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSOURCEOBSERVATIONNUM(QUANTITY value) {
        this.sourceobservationnum = value;
    }

    /**
     * Gets the value of the overrideobservation property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOVERRIDEOBSERVATION() {
        return overrideobservation;
    }

    /**
     * Sets the value of the overrideobservation property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOVERRIDEOBSERVATION(String value) {
        this.overrideobservation = value;
    }

    /**
     * Gets the value of the recommendedrepairdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getRECOMMENDEDREPAIRDATE() {
        return recommendedrepairdate;
    }

    /**
     * Sets the value of the recommendedrepairdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setRECOMMENDEDREPAIRDATE(DATETIME value) {
        this.recommendedrepairdate = value;
    }

    /**
     * Gets the value of the currencyid property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getCURRENCYID() {
        return currencyid;
    }

    /**
     * Sets the value of the currencyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setCURRENCYID(CURRENCYID_Type value) {
        this.currencyid = value;
    }

    /**
     * Gets the value of the estimatedlaborcost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDLABORCOST() {
        return estimatedlaborcost;
    }

    /**
     * Sets the value of the estimatedlaborcost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDLABORCOST(AMOUNT value) {
        this.estimatedlaborcost = value;
    }

    /**
     * Gets the value of the estimatedmaterialcost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDMATERIALCOST() {
        return estimatedmaterialcost;
    }

    /**
     * Sets the value of the estimatedmaterialcost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDMATERIALCOST(AMOUNT value) {
        this.estimatedmaterialcost = value;
    }

    /**
     * Gets the value of the estimatedmiscellaneouscost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDMISCELLANEOUSCOST() {
        return estimatedmiscellaneouscost;
    }

    /**
     * Sets the value of the estimatedmiscellaneouscost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDMISCELLANEOUSCOST(AMOUNT value) {
        this.estimatedmiscellaneouscost = value;
    }

    /**
     * Gets the value of the estimatedtotalcost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getESTIMATEDTOTALCOST() {
        return estimatedtotalcost;
    }

    /**
     * Sets the value of the estimatedtotalcost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setESTIMATEDTOTALCOST(AMOUNT value) {
        this.estimatedtotalcost = value;
    }

    /**
     * Gets the value of the capitalplanrequestid property.
     * 
     * @return
     *     possible object is
     *     {@link CAPITALPLANREQUESTID_Type }
     *     
     */
    public CAPITALPLANREQUESTID_Type getCAPITALPLANREQUESTID() {
        return capitalplanrequestid;
    }

    /**
     * Sets the value of the capitalplanrequestid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CAPITALPLANREQUESTID_Type }
     *     
     */
    public void setCAPITALPLANREQUESTID(CAPITALPLANREQUESTID_Type value) {
        this.capitalplanrequestid = value;
    }

    /**
     * Gets the value of the nonconformitymergeinto property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNONCONFORMITYMERGEINTO() {
        return nonconformitymergeinto;
    }

    /**
     * Sets the value of the nonconformitymergeinto property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNONCONFORMITYMERGEINTO(String value) {
        this.nonconformitymergeinto = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the createdby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Sets the value of the createdby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Gets the value of the updatedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Sets the value of the updatedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

    /**
     * Gets the value of the dateupdated property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEUPDATED() {
        return dateupdated;
    }

    /**
     * Sets the value of the dateupdated property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEUPDATED(DATETIME value) {
        this.dateupdated = value;
    }

}
